summaryrefslogtreecommitdiffstats
path: root/Source/cmMakefile.h
diff options
context:
space:
mode:
authorBen Boeckel <ben.boeckel@kitware.com>2014-02-06 19:05:57 (GMT)
committerBrad King <brad.king@kitware.com>2014-03-08 18:05:29 (GMT)
commit310ef08fed57b1c60ea8dc8ed98520e2cb0bff4e (patch)
tree89b17e537dd73551de0c5c225b18a6bfbee2ed8b /Source/cmMakefile.h
parent24e8b929eef74098d4ddf4581619322e0f4b5108 (diff)
downloadCMake-310ef08fed57b1c60ea8dc8ed98520e2cb0bff4e.zip
CMake-310ef08fed57b1c60ea8dc8ed98520e2cb0bff4e.tar.gz
CMake-310ef08fed57b1c60ea8dc8ed98520e2cb0bff4e.tar.bz2
stringapi: Use strings for source names
Diffstat (limited to 'Source/cmMakefile.h')
-rw-r--r--Source/cmMakefile.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/Source/cmMakefile.h b/Source/cmMakefile.h
index 559d49c..a8ad1e2 100644
--- a/Source/cmMakefile.h
+++ b/Source/cmMakefile.h
@@ -332,7 +332,7 @@ public:
/**
* Add a root source group for consideration when adding a new source.
*/
- void AddSourceGroup(const char* name, const char* regex=0);
+ void AddSourceGroup(const std::string& name, const char* regex=0);
/**
* Add a source group for consideration when adding a new source.
@@ -555,14 +555,14 @@ public:
/** Get a cmSourceFile pointer for a given source name, if the name is
* not found, then a null pointer is returned.
*/
- cmSourceFile* GetSource(const char* sourceName) const;
+ cmSourceFile* GetSource(const std::string& sourceName) const;
/** Get a cmSourceFile pointer for a given source name, if the name is
* not found, then create the source file and return it. generated
* indicates if it is a generated file, this is used in determining
* how to create the source file instance e.g. name
*/
- cmSourceFile* GetOrCreateSource(const char* sourceName,
+ cmSourceFile* GetOrCreateSource(const std::string& sourceName,
bool generated = false);
/**
@@ -773,7 +773,7 @@ public:
* Is there a source file that has the provided source file as an output?
* if so then return it
*/
- cmSourceFile *GetSourceFileWithOutput(const char *outName) const;
+ cmSourceFile *GetSourceFileWithOutput(const std::string& outName) const;
/**
* Add a macro to the list of macros. The arguments should be name of the
@@ -1030,12 +1030,12 @@ private:
bool GeneratingBuildSystem;
/**
* Old version of GetSourceFileWithOutput(const char*) kept for
* backward-compatibility. It implements a linear search and support
* relative file paths. It is used as a fall back by
- * GetSourceFileWithOutput(const char*).
+ * GetSourceFileWithOutput(const std::string&).
*/
- cmSourceFile *LinearGetSourceFileWithOutput(const char *cname) const;
+ cmSourceFile *LinearGetSourceFileWithOutput(const std::string& cname) const;
// A map for fast output to input look up.
#if defined(CMAKE_BUILD_WITH_CMAKE)
@@ -1030,12 +1030,12 @@ private:
bool GeneratingBuildSystem;
/**
- * Old version of GetSourceFileWithOutput(const char*) kept for
+ * Old version of GetSourceFileWithOutput(const std::string&) kept for
* backward-compatibility. It implements a linear search and support
* relative file paths. It is used as a fall back by